===========================
Database Service User Guide
===========================

The Database service provides scalable and reliable cloud provisioning
functionality for both relational and non-relational database engines.
Users can quickly and easily use database features without the burden of
handling complex administrative tasks.

.. toctree::
   :maxdepth: 1

   instance-status.rst
   create-db.rst
   manage-db-and-users.rst
   backup-db.rst
   manage-db-config.rst
   set-up-replication.rst
   upgrade-datastore.rst
   set-up-clustering.rst
   upgrade-cluster-datastore.rst
